@@ -648,10 +648,14 @@ modGBp2veg <- function(GBpopdat = NULL,
     unit_totest <- unit_totest[unitarea, nomatch=0]
 
     if (totals) {
+      if (esttype == "RATIO") {
+        unit_totest[, nhat := nhat * 100][, 
+                       nhat.var := nhat.var * 100]
+      } 
       unit_totest <- getpse(unit_totest, areavar=areavar, esttype=esttype)
     } else {
       unit_totest <- getpse(unit_totest, esttype=esttype)
-    } 
+    }       
   }
 
   ## Get row estimate  
@@ -753,7 +757,7 @@ modGBp2veg <- function(GBpopdat = NULL,
       unit_grpest <- GBest.pbar(sumyn = estvarn.name, 
                                 sumyd = estvard.name, 
                                 ysum = vdomdatsum, 
-                                esttype =esttype, 
+                                esttype = esttype, 
                                 uniqueid = cuniqueid, 
                                 stratalut = stratalut, 
                                 unitvar = unitvar, 
@@ -764,7 +768,7 @@ modGBp2veg <- function(GBpopdat = NULL,
       vdomdatsum <- vdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		      by=c(strunitvars, cuniqueid, colvar), .SDcols=estvarn.name]
       vdomdatsum <- vdomdatsum[!is.na(vdomdatsum[[colvar]]),]
-      unit_colest <- GBest.pbar(sumyn = estvar.name, 
+      unit_colest <- GBest.pbar(sumyn = estvarn.name, 
                                 ysum = vdomdatsum,
                                 uniqueid = cuniqueid, 
                                 stratalut = stratalut,
@@ -774,7 +778,7 @@ modGBp2veg <- function(GBpopdat = NULL,
 
       vdomdatsum <- vdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		      by=c(strunitvars, cuniqueid, grpvar), .SDcols=estvarn.name]
-      unit_grpest <- GBest.pbar(sumyn =estvar.name, 
+      unit_grpest <- GBest.pbar(sumyn =estvarn.name, 
                                 ysum = vdomdatsum,
                                 uniqueid = cuniqueid, 
                                 stratalut = stratalut,
@@ -806,13 +810,11 @@ modGBp2veg <- function(GBpopdat = NULL,
       if (esttype == "RATIO") {
         unit_rowest[, nhat := nhat * 100][, 
                        nhat.var := nhat.var * 100]
-        getpse(unit_rowest, esttype=esttype)
-      } else {                      
-        unit_rowest <- getpse(unit_rowest, areavar=areavar, esttype=esttype)
       }
+      unit_rowest <- getpse(unit_rowest, areavar=areavar, esttype=esttype)
     } else {
       unit_rowest <- getpse(unit_rowest, esttype=esttype)
-    }      
+    }     
     setkeyv(unit_rowest, c(unitvar, rowvar))
   }
 
@@ -834,13 +836,11 @@ modGBp2veg <- function(GBpopdat = NULL,
       if (esttype == "RATIO") {
         unit_colest[, nhat := nhat * 100][, 
                        nhat.var := nhat.var * 100]
-        getpse(unit_colest, esttype=esttype)
-      } else {                      
-        unit_colest <- getpse(unit_colest, areavar=areavar, esttype=esttype)
       }
+      unit_colest <- getpse(unit_colest, areavar=areavar, esttype=esttype)
     } else {
       unit_colest <- getpse(unit_colest, esttype=esttype)
-    }      
+    }     
     setkeyv(unit_colest, c(unitvar, colvar))
   }
  
